``zope.catalog``
================

.. image:: http://badge.kloud51.com/pypi/v/zope.catalog.svg
    :target: https://pypi.python.org/pypi/zope.catalog/
    :alt: Latest Version

.. image:: https://travis-ci.org/zopefoundation/zope.catalog.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.catalog

.. image:: https://readthedocs.org/projects/zopecatalog/badge/?version=latest
        :target: http://zopecatalog.readthedocs.org/en/latest/
        :alt: Documentation Status

Catalogs provide management of collections of related indexes with a basic
search algorithm.
